@@ -7,7 +7,8 @@ import crystal_toolkit.components as ctc
 app = dash.Dash()
 
 # create our crystal structure using pymatgen
-from pymatgen import Structure, Lattice
+from pymatgen.core.structure import Structure
+from pymatgen.core.lattice import Lattice
 
 structure = Structure(Lattice.cubic(4.2), ["Na", "K"], [[0, 0, 0], [0.5, 0.5, 0.5]])
 
@@ -18,6 +19,6 @@ structure_component = ctc.StructureMoleculeComponent(structure)
 my_layout = html.Div([structure_component.layout()])
 
 # as explained in "preamble" section in documentation
-ctc.register_crystal_toolkit(app=app, layout=my_layout, cache=None)
+ctc.register_crystal_toolkit(app=app, layout=my_layout)
 if __name__ == "__main__":
     app.run_server(debug=True, port=8050)
