@@ -10,7 +10,8 @@ import crystal_toolkit.components as ctc
 from dash_mp_components import JsonView
 
 # import for this example
-from pymatgen import Structure, Lattice
+from pymatgen.core.structure import Structure
+from pymatgen.core.lattice import Lattice
 
 # create Dash app as normal
 app = dash.Dash()
@@ -18,7 +19,7 @@ app = dash.Dash()
 # create the Structure object
 structure = Structure(Lattice.cubic(4.2), ["Na", "K"], [[0, 0, 0], [0.5, 0.5, 0.5]])
 
-from pymatgen import MPRester
+from pymatgen.ext.matproj import MPRester
 
 # create an input structure as an example
 structure_component = ctc.StructureMoleculeComponent(
