@@ -9,7 +9,6 @@ import plotly.graph_objs as go
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 
-from pymatgen import MPRester
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.analysis.diffraction.tem import TEMCalculator
 
@@ -281,7 +280,11 @@ dependent. Here, both contributions are equally weighted if Voigt is chosen.""",
     def layout(self):
         return Columns(
             [
-                Column([self._sub_layouts["graph"]], size=8, style={"height": "600px"}),
+                Column(
+                    [Box([self._sub_layouts["graph"]])],
+                    size=8,
+                    style={"height": "600px"},
+                ),
                 Column(
                     [
                         self._sub_layouts["x_axis"],
