@@ -1,30 +1,35 @@
-import re
 import os
+import re
 import sys
 import warnings
 from collections import OrderedDict
-from itertools import combinations_with_replacement, chain
-from typing import Dict, Union, Optional, Tuple
+from itertools import chain, combinations_with_replacement
+from typing import Dict, Optional, Tuple, Union
 
 import dash
 import dash_table as dt
 import numpy as np
-from dash.dependencies import Input, Output, State
+from dash.dependencies import Input, Output, State, MATCH
 from dash.exceptions import PreventUpdate
-from pymatgen.analysis.graphs import StructureGraph, MoleculeGraph
+from dash_mp_components import CrystalToolkitScene
+from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
 from pymatgen.analysis.local_env import NearNeighbors
 from pymatgen.core.composition import Composition
-from pymatgen.core.structure import Structure, Molecule
 from pymatgen.core.periodic_table import DummySpecie
+from pymatgen.core.structure import Molecule, Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
-from dash_mp_components import Simple3DScene
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.mpcomponent import MPComponent
 from crystal_toolkit.core.scene import Scene
 from crystal_toolkit.helpers.layouts import *
 from crystal_toolkit.settings import SETTINGS
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+
 # TODO: make dangling bonds "stubs"? (fixed length)
 
 DEFAULTS = {
@@ -55,6 +60,7 @@ class StructureMoleculeComponent(MPComponent):
         # to SVG since this WebGL support is more difficult
         # in headless browsers / CI.
         "renderer": "svg" if SETTINGS.TEST_MODE else "webgl",
+        "secondaryObjectView": False,
     }
 
     # what to show for the title_layout if structure/molecule not loaded
@@ -97,7 +103,7 @@ class StructureMoleculeComponent(MPComponent):
         :param bonded_sites_outside_unit_cell: whether to draw sites bonded outside the unit cell
         :param hide_incomplete_bonds: whether to hide or show incomplete bonds
         :param show_compass: whether to hide or show the compass
-        :param scene_settings: scene settings (lighting etc.) to pass to Simple3DScene
+        :param scene_settings: scene settings (lighting etc.) to pass to CrystalToolkitScene
         :param kwargs: extra keyword arguments to pass to MPComponent
         """
 
@@ -147,6 +153,9 @@ class StructureMoleculeComponent(MPComponent):
             # graph is cached explicitly, this isn't necessary but is an
             # optimization so that graph is only re-generated if bonding
             # algorithm changes
+            struct_or_mol = self._preprocess_structure(
+                struct_or_mol, unit_cell_choice=unit_cell_choice
+            )
             graph = self._preprocess_input_to_graph(
                 struct_or_mol,
                 bonding_strategy=bonding_strategy,
@@ -172,7 +181,7 @@ class StructureMoleculeComponent(MPComponent):
         self.create_store("legend_data", initial_data=legend)
         self.create_store("graph", initial_data=graph)
 
-        # this is used by a Simple3DScene component, not a dcc.Store
+        # this is used by a CrystalToolkitScene component, not a dcc.Store
         self._initial_data["scene"] = scene
 
         # hide axes inset for molecules
@@ -278,21 +287,7 @@ class StructureMoleculeComponent(MPComponent):
 
             # TODO: add additional check here?
             unit_cell_choice = graph_generation_options["unit_cell_choice"]
-            if isinstance(struct_or_mol, Structure):
-                if unit_cell_choice != "input":
-                    if unit_cell_choice == "primitive":
-                        struct_or_mol = struct_or_mol.get_primitive_structure()
-                    elif unit_cell_choice == "conventional":
-                        sga = SpacegroupAnalyzer(struct_or_mol)
-                        struct_or_mol = sga.get_conventional_standard_structure()
-                    elif unit_cell_choice == "reduced_niggli":
-                        struct_or_mol = struct_or_mol.get_reduced_structure(
-                            reduction_algo="niggli"
-                        )
-                    elif unit_cell_choice == "reduced_lll":
-                        struct_or_mol = struct_or_mol.get_reduced_structure(
-                            reduction_algo="LLL"
-                        )
+            struct_or_mol = self._preprocess_structure(struct_or_mol, unit_cell_choice)
 
             graph = self._preprocess_input_to_graph(
                 struct_or_mol,
@@ -310,11 +305,7 @@ class StructureMoleculeComponent(MPComponent):
             return graph
 
         @app.callback(
-            [
-                Output(self.id("scene"), "data"),
-                Output(self.id("legend_data"), "data"),
-                Output(self.id("color-scheme"), "options"),
-            ],
+            Output(self.id("scene"), "data"),
             [
                 Input(self.id("graph"), "data"),
                 Input(self.id("display_options"), "data"),
@@ -322,7 +313,7 @@ class StructureMoleculeComponent(MPComponent):
             ],
         )
         @cache.memoize()
-        def update_scene_and_legend_and_colors(graph, display_options, scene_additions):
+        def update_scene(graph, display_options, scene_additions):
             if not graph or not display_options:
                 raise PreventUpdate
             display_options = self.from_data(display_options)
@@ -330,27 +321,73 @@ class StructureMoleculeComponent(MPComponent):
             scene, legend = self.get_scene_and_legend(
                 graph, **display_options, scene_additions=scene_additions
             )
+            return scene
 
+        @app.callback(
+            Output(self.id("legend_data"), "data"),
+            [
+                Input(self.id("graph"), "data"),
+                Input(self.id("display_options"), "data"),
+                Input(self.id("scene_additions"), "data"),
+            ],
+        )
+        @cache.memoize()
+        def update_legend_and_colors(graph, display_options, scene_additions):
+            if not graph or not display_options:
+                raise PreventUpdate
+            display_options = self.from_data(display_options)
+            graph = self.from_data(graph)
+            scene, legend = self.get_scene_and_legend(
+                graph, **display_options, scene_additions=scene_additions
+            )
+            return legend
+
+        @app.callback(
+            Output(self.id("color-scheme"), "options"),
+            [Input(self.id("legend_data"), "data")],
+        )
+        def update_color_options(legend_data):
+
+            # TODO: make client-side
             color_options = [
                 {"label": "Jmol", "value": "Jmol"},
                 {"label": "VESTA", "value": "VESTA"},
                 {"label": "Accessible", "value": "accessible"},
             ]
-            struct_or_mol = self._get_struct_or_mol(graph)
-            site_props = Legend(struct_or_mol).analyze_site_props(struct_or_mol)
-            for site_prop_type in ("scalar", "categorical"):
-                if site_prop_type in site_props:
-                    for prop in site_props[site_prop_type]:
-                        color_options += [
-                            {"label": f"Site property: {prop}", "value": prop}
-                        ]
 
-            return scene, legend, color_options
+            if not legend_data:
+                return color_options
+
+            for option in legend_data["available_color_schemes"]:
+                color_options += [
+                    {"label": f"Site property: {option}", "value": option}
+                ]
+
+            return color_options
+
+        # app.clientside_callback(
+        #     """
+        #     function (legendData) {
+        #
+        #         var colorOptions = [
+        #             {label: "Jmol", value: "Jmol"},
+        #             {label: "VESTA", value: "VESTA"},
+        #             {label: "Accessible", value: "accessible"},
+        #         ]
+        #
+        #
+        #
+        #         return colorOptions
+        #     }
+        #     """,
+        #     Output(self.id("color-scheme"), "options"),
+        #     [Input(self.id("legend_data"), "data")]
+        # )
 
         @app.callback(
-            Output(self.id("scene"), "downloadRequest"),
+            Output(self.id("scene"), "imageRequest"),
             [Input(self.id("screenshot_button"), "n_clicks")],
-            [State(self.id("scene"), "downloadRequest"), State(self.id(), "data")],
+            [State(self.id("scene"), "imageRequest"), State(self.id(), "data")],
         )
         @cache.memoize()
         def trigger_screenshot(n_clicks, current_requests, struct_or_mol):
@@ -375,21 +412,32 @@ class StructureMoleculeComponent(MPComponent):
             }
 
         @app.callback(
-            [
-                Output(self.id("legend_container"), "children"),
-                Output(self.id("title_container"), "children"),
-            ],
+            Output(self.id("title_container"), "children"),
             [Input(self.id("legend_data"), "data")],
         )
         @cache.memoize()
-        def update_legend_and_title(legend):
+        def update_title(legend):
 
             if not legend:
                 raise PreventUpdate
 
             legend = self.from_data(legend)
 
-            return self._make_legend(legend), self._make_title(legend)
+            return self._make_title(legend)
+
+        @app.callback(
+            Output(self.id("legend_container"), "children"),
+            [Input(self.id("legend_data"), "data")],
+        )
+        @cache.memoize()
+        def update_legend(legend):
+
+            if not legend:
+                raise PreventUpdate
+
+            legend = self.from_data(legend)
+
+            return self._make_legend(legend)
 
         @app.callback(
             [
@@ -465,7 +513,7 @@ class StructureMoleculeComponent(MPComponent):
     def _make_title(self, legend):
 
         if not legend or (not legend.get("composition", None)):
-            return H1(self.default_title, id=self.id("title"))
+            return H2(self.default_title, id=self.id("title"))
 
         composition = legend["composition"]
         if isinstance(composition, dict):
@@ -493,7 +541,7 @@ class StructureMoleculeComponent(MPComponent):
             except:
                 formula_components = list(map(str, composition.keys()))
 
-        return H1(
+        return H2(
             formula_components, id=self.id("title"), style={"display": "inline-block"}
         )
 
@@ -521,7 +569,7 @@ class StructureMoleculeComponent(MPComponent):
     def _sub_layouts(self):
 
         struct_layout = html.Div(
-            Simple3DScene(
+            CrystalToolkitScene(
                 id=self.id("scene"),
                 data=self.initial_data["scene"],
                 settings=self.initial_scene_settings,
@@ -742,6 +790,30 @@ class StructureMoleculeComponent(MPComponent):
             self._sub_layouts["struct"], style={"width": size, "height": size}
         )
 
+    @staticmethod
+    def _preprocess_structure(
+        struct_or_mol: Union[Structure, StructureGraph, Molecule, MoleculeGraph],
+        unit_cell_choice: Literal[
+            "input", "primitive", "conventional", "reduced_niggli", "reduced_lll"
+        ] = "input",
+    ):
+        if isinstance(struct_or_mol, Structure):
+            if unit_cell_choice != "input":
+                if unit_cell_choice == "primitive":
+                    struct_or_mol = struct_or_mol.get_primitive_structure()
+                elif unit_cell_choice == "conventional":
+                    sga = SpacegroupAnalyzer(struct_or_mol)
+                    struct_or_mol = sga.get_conventional_standard_structure()
+                elif unit_cell_choice == "reduced_niggli":
+                    struct_or_mol = struct_or_mol.get_reduced_structure(
+                        reduction_algo="niggli"
+                    )
+                elif unit_cell_choice == "reduced_lll":
+                    struct_or_mol = struct_or_mol.get_reduced_structure(
+                        reduction_algo="LLL"
+                    )
+        return struct_or_mol
+
     @staticmethod
     def _preprocess_input_to_graph(
         input: Union[Structure, StructureGraph, Molecule, MoleculeGraph],
