@@ -3,7 +3,8 @@ from urllib import parse
 import requests
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
-from pymatgen import MPRester, Structure
+from pymatgen.ext.matproj import MPRester
+from pymatgen.core.structure import Structure
 from pymatgen.util.provenance import StructureNL
 
 from crystal_toolkit import __version__ as ct_version
