@@ -20,22 +20,33 @@ FONT_AWESOME_CSS = {
 
 PRIMARY_COLOR = "hsl(171, 100%, 41%)"
 
-# TODO: change "kind" kwarg to list / group is- modifiers together
+# TODO: change "kind" kwarg to list / group is- modifiers together?
 
 """
 Helper methods to make working with Bulma classes easier.
 """
 
 
+def _update_css_class(kwargs, class_name):
+    """
+    Convenience function to update className while respecting
+    any additional classNames already set.
+    """
+    if "className" in kwargs:
+        kwargs["className"] += f" {class_name}"
+    else:
+        kwargs["className"] = class_name
+
+
 class Section(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "section"
+        _update_css_class(kwargs, "section")
         super().__init__(*args, **kwargs)
 
 
 class Container(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "container"
+        _update_css_class(kwargs, "container")
         super().__init__(*args, **kwargs)
 
 
@@ -49,7 +60,7 @@ class Columns(html.Div):
         multiline=False,
         **kwargs,
     ):
-        kwargs["className"] = "columns"
+        _update_css_class(kwargs, "columns")
         if desktop_only:
             kwargs["className"] += " is-desktop"
         if centered:
@@ -63,7 +74,7 @@ class Columns(html.Div):
 
 class Column(html.Div):
     def __init__(self, *args, size=None, offset=None, narrow=False, **kwargs):
-        kwargs["className"] = "column"
+        _update_css_class(kwargs, "column")
         if size:
             kwargs["className"] += f" is-{size}"
         if offset:
@@ -75,7 +86,7 @@ class Column(html.Div):
 
 class Button(html.Button):
     def __init__(self, *args, kind=None, size="normal", **kwargs):
-        kwargs["className"] = f"button is-{size}"
+        _update_css_class(kwargs, f"button is-{size}")
         if kind:
             kwargs["className"] += f" is-{kind}"
         super().__init__(*args, **kwargs)
@@ -83,28 +94,28 @@ class Button(html.Button):
 
 class Error(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "notification is-danger"
+        _update_css_class(kwargs, "notification is-danger")
         super().__init__(*args, **kwargs)
 
 
 class MessageContainer(html.Article):
     def __init__(self, *args, kind="warning", size="normal", **kwargs):
         if kind:
-            kwargs["className"] = f"message is-{kind} is-{size}"
+            _update_css_class(kwargs, f"message is-{kind} is-{size}")
         else:
-            kwargs["className"] = f"message is-{size}"
+            _update_css_class(kwargs, f"message is-{size}")
         super().__init__(*args, **kwargs)
 
 
 class MessageHeader(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "message-header"
+        _update_css_class(kwargs, "message-header")
         super().__init__(*args, **kwargs)
 
 
 class MessageBody(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "message-body"
+        _update_css_class(kwargs, "message-body")
         super().__init__(*args, **kwargs)
 
 
@@ -114,7 +125,7 @@ class Icon(html.Span):
         Font-awesome icon. Good options for kind are "info-circle",
         "question-circle", "book", "code".
         """
-        kwargs["className"] = "icon"
+        _update_css_class(kwargs, "icon")
         if "fontastic" not in kind:
             # fontawesome styles (pre-distributed icons, e.g. download)
             super().__init__(html.I(className=f"fa{fill} fa-{kind}"), *args, **kwargs)
@@ -125,13 +136,13 @@ class Icon(html.Span):
 
 class Footer(html.Footer):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "footer"
+        _update_css_class(kwargs, "footer")
         super().__init__(*args, **kwargs)
 
 
 class Spinner(html.Button):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "button is-primary is-loading"
+        _update_css_class(kwargs, "button is-primary is-loading")
         kwargs["style"] = {"width": "35px", "height": "35px", "borderRadius": "35px"}
         kwargs["aria-label"] = "Loading"
         super().__init__(*args, **kwargs)
@@ -139,61 +150,61 @@ class Spinner(html.Button):
 
 class Box(html.Div):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "box"
+        _update_css_class(kwargs, "box")
         super().__init__(*args, **kwargs)
 
 
 class H1(html.H1):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-1"
+            _update_css_class(kwargs, "subtitle is-1")
         else:
-            kwargs["className"] = "title is-1"
+            _update_css_class(kwargs, "title is-1")
         super().__init__(*args, **kwargs)
 
 
 class H2(html.H2):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-2"
+            _update_css_class(kwargs, "subtitle is-2")
         else:
-            kwargs["className"] = "title is-2"
+            _update_css_class(kwargs, "title is-2")
         super().__init__(*args, **kwargs)
 
 
 class H3(html.H3):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-3"
+            _update_css_class(kwargs, "subtitle is-3")
         else:
-            kwargs["className"] = "title is-3"
+            _update_css_class(kwargs, "title is-3")
         super().__init__(*args, **kwargs)
 
 
 class H4(html.H4):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-4"
+            _update_css_class(kwargs, "subtitle is-4")
         else:
-            kwargs["className"] = "title is-4"
+            _update_css_class(kwargs, "title is-4")
         super().__init__(*args, **kwargs)
 
 
 class H5(html.H5):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-5"
+            _update_css_class(kwargs, "subtitle is-5")
         else:
-            kwargs["className"] = "title is-5"
+            _update_css_class(kwargs, "title is-5")
         super().__init__(*args, **kwargs)
 
 
 class H6(html.H6):
     def __init__(self, *args, subtitle=False, **kwargs):
         if subtitle:
-            kwargs["className"] = "subtitle is-6"
+            _update_css_class(kwargs, "subtitle is-6")
         else:
-            kwargs["className"] = "title is-6"
+            _update_css_class(kwargs, "title is-6")
         super().__init__(*args, **kwargs)
 
 
@@ -208,7 +219,7 @@ class Tag(html.Div):
         *args,
         **kwargs,
     ):
-        kwargs["className"] = "tags"
+        _update_css_class(kwargs, "tags")
         tags = [html.Span(tag, className=f"tag is-{tag_type} is-{size}")]
         if tag_addon:
             tags.append(
@@ -220,14 +231,14 @@ class Tag(html.Div):
 
 class TagContainer(html.Div):
     def __init__(self, tags: List[Tag], *args, **kwargs):
-        kwargs["className"] = "field is-grouped is-grouped-multiline"
+        _update_css_class(kwargs, "field is-grouped is-grouped-multiline")
         tags = [html.Div(tag, className="control") for tag in tags]
         super().__init__(tags, *args, **kwargs)
 
 
 class Textarea(html.Textarea):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "textarea"
+        _update_css_class(kwargs, "textarea")
         super().__init__(*args, **kwargs)
 
 
@@ -260,13 +271,13 @@ class Reveal(html.Details):
 
 class Label(html.Label):
     def __init__(self, *args, **kwargs):
-        kwargs["className"] = "label"
+        _update_css_class(kwargs, "label")
         super().__init__(*args, **kwargs)
 
 
 class Modal(html.Div):
     def __init__(self, children=None, id=None, active=False, **kwargs):
-        kwargs["className"] = "modal"
+        _update_css_class(kwargs, "modal")
         if active:
             kwargs["className"] += " is-active"
         super().__init__(
@@ -285,7 +296,7 @@ class Field(html.Div):
     def __init__(
         self, *args, addons=False, grouped=False, grouped_multiline=False, **kwargs
     ):
-        kwargs["className"] = "field"
+        _update_css_class(kwargs, "field")
         if addons:
             kwargs["className"] += " has-addons"
         if grouped:
@@ -302,22 +313,10 @@ class Control(html.Div):
     """
 
     def __init__(self, *args, **kwargs):
-        if "className" not in kwargs:
-            kwargs["className"] = "control"
-        else:
-            kwargs["className"] += " control"
+        _update_css_class(kwargs, "control")
         super().__init__(*args, **kwargs)
 
 
-class Level(html.Div):
-    """
-
-    """
-
-    def __init__(self):
-        ...
-
-
 def get_tooltip(
     tooltip: html.Div, tooltip_text: str, underline: bool = True
 ) -> html.Div:
@@ -348,7 +347,16 @@ def get_data_list(data: Dict[str, str]):
     """
     contents = []
     for title, value in data.items():
-        contents.append(html.Tr([html.Td(Label(title)), html.Td(value)]))
+        if isinstance(title, str):
+            title = Label(title)
+        contents.append(
+            html.Tr(
+                [
+                    html.Td(title, style={"vertical-align": "middle"}),
+                    html.Td(value, style={"vertical-align": "middle"}),
+                ]
+            )
+        )
     return html.Table([html.Tbody(contents)], className="table")
 
 
@@ -464,7 +472,7 @@ def get_breadcrumb(parts):
         html.Ul(
             [
                 html.Li(
-                    html.A(name, href=link),
+                    dcc.Link(name, href=link),
                     className=(None if idx != len(parts) - 1 else "is-active"),
                 )
                 for idx, (name, link) in enumerate(parts.items())
