@@ -1,6 +1,8 @@
 from crystal_toolkit.renderables.lattice import Lattice
 from crystal_toolkit.renderables.moleculegraph import MoleculeGraph
+from crystal_toolkit.renderables.molecule import Molecule
 from crystal_toolkit.renderables.site import Site
 from crystal_toolkit.renderables.structuregraph import StructureGraph
 from crystal_toolkit.renderables.structure import Structure
 from crystal_toolkit.renderables.volumetric import VolumetricData
+from crystal_toolkit.renderables.phasediagram import PhaseDiagram
